import{S as E,g as G,V as H,j as I,C as J,p as m,c as _,x as h,r as b,t as g,a as x,f as A,L as K,i as S}from"./CId4BCie.js";import"./CWj6FrbW.js";import{t as k,a as f,c as L}from"./BKnx-tix.js";import{s as d}from"./D0aaoSU3.js";import{s as B,b as C,g as M}from"./FgnODE38.js";import{p as u,d as P,r as y,i as T}from"./B0ThxVmG.js";import{C as N}from"./BRITuSBg.js";function re(i,e,t){E(()=>{var r=G(()=>e(i,t==null?void 0:t())||{});if(t&&(r!=null&&r.update)){var a=!1,s={};H(()=>{var l=t();I(l),a&&J(s,l)&&(s=l,r.update(l))}),a=!0}if(r!=null&&r.destroy)return()=>r.destroy()})}var O=k("<nav><!></nav>");function se(i,e){m(e,!0);let t=u(e,"ref",15),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=O();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(()=>s=B(a,s,{class:e.class,"aria-label":"breadcrumb",...r})),f(i,a),x()}var Q=k("<li><!></li>");function le(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=Q();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(n=>s=B(a,s,{class:n,...r}),[()=>C("inline-flex items-center gap-1.5",e.class)]),f(i,a),x()}var R=k("<li><!></li>");function ne(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=R();let s;var l=_(a);{var n=c=>{var w=L(),q=A(w);d(q,()=>e.children??h),f(c,w)},j=c=>{N(c,{})};T(l,c=>{e.children?c(n):c(j,!1)})}b(a),P(a,c=>t(c),()=>t()),g(c=>s=B(a,s,{role:"presentation","aria-hidden":"true",class:c,...r}),[()=>C("[&>svg]:size-3.5",e.class)]),f(i,a),x()}var U=k("<a><!></a>");function ie(i,e){m(e,!0);let t=u(e,"ref",15,null),r=u(e,"href",3,void 0),a=y(e,["$$slots","$$events","$$legacy","ref","class","href","child","children"]);const s=K(()=>({class:C("hover:text-foreground transition-colors",e.class),href:r(),...a})),l=M(),[n,j]=l;var c=L(),w=A(c);{var q=v=>{var o=L(),F=A(o);d(F,()=>e.child,()=>({props:S(s)})),f(v,o)},V=v=>{var o=U();let F;var D=_(o);d(D,()=>e.children??h),b(o),P(o,z=>t(z),()=>t()),g(z=>F=B(o,F,{...z}),[()=>j({...S(s)},[{attribute_name:"href",lang_attribute_name:"hreflang"}])]),f(v,o)};T(w,v=>{e.child?v(q):v(V,!1)})}f(i,c),x()}var W=k("<ol><!></ol>");function ce(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=W();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(n=>s=B(a,s,{class:n,...r}),[()=>C("flex flex-wrap items-center gap-1.5 break-words text-sm text-muted-foreground sm:gap-2.5",e.class)]),f(i,a),x()}var X=k("<span><!></span>");function fe(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=X();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(n=>s=B(a,s,{role:"link","aria-disabled":"true","aria-current":"page",class:n,...r}),[()=>C("font-normal text-foreground",e.class)]),f(i,a),x()}export{se as B,re as a,ce as b,le as c,fe as d,ie as e,ne as f};
