import"./CWj6FrbW.js";import{p as C,f as t,L as R,i as B,a as L,s as w,x as K,B as N}from"./CId4BCie.js";import{c as _,a as e,t as x}from"./BKnx-tix.js";import{p as h,c as r,b,r as M,i as O}from"./B0ThxVmG.js";import{s as Q}from"./D0aaoSU3.js";import{t as S,a as T,P as U}from"./FgnODE38.js";import{D as V,a as W,b as Y,X as Z,c as aa}from"./BRITuSBg.js";function X(...s){return S(T(s))}function ta(s,a){C(a,!0);let o=h(a,"ref",15,null),i=M(a,["$$slots","$$events","$$legacy","ref","class"]);var n=_(),l=t(n);const d=R(()=>X("fixed inset-0 z-50 bg-black/80  data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0",a.class));r(l,()=>V,(c,f)=>{f(c,b({get class(){return B(d)}},()=>i,{get ref(){return o()},set ref(p){o(p)}}))}),e(s,n),L()}var ea=x('<!> <span class="sr-only">Close</span>',1),sa=x("<!> <!>",1),oa=x("<!> <!>",1);function va(s,a){C(a,!0);let o=h(a,"ref",15,null),i=h(a,"hideClose",3,!1),n=M(a,["$$slots","$$events","$$legacy","ref","class","portalProps","hideClose","children"]);var l=_(),d=t(l);r(d,()=>ra,(c,f)=>{f(c,b(()=>a.portalProps,{children:(p,na)=>{var P=oa(),y=t(P);r(y,()=>ta,(u,g)=>{g(u,{})});var j=w(y,2);const q=R(()=>X("fixed left-[50%] top-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border bg-background p-6 shadow-lg duration-200 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-left-1/2 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-left-1/2 data-[state=open]:slide-in-from-top-[48%] sm:rounded-lg",a.class));r(j,()=>W,(u,g)=>{g(u,b({get class(){return B(q)}},()=>n,{get ref(){return o()},set ref(m){o(m)},children:(m,la)=>{var $=sa(),D=t($);Q(D,()=>a.children??K);var A=w(D,2);{var E=v=>{var z=_(),F=t(z);r(F,()=>Y,(G,H)=>{H(G,{class:"absolute right-4 top-4 rounded-sm opacity-70 ring-offset-background transition-opacity hover:opacity-100 focus:outline-none focus:ring-2 focus:ring-ring focus:ring-offset-2 disabled:pointer-events-none",children:(I,ia)=>{var k=ea(),J=t(k);Z(J,{class:"size-4"}),N(2),e(I,k)},$$slots:{default:!0}})}),e(v,z)};O(A,v=>{i()||v(E)})}e(m,$)},$$slots:{default:!0}}))}),e(p,P)},$$slots:{default:!0}}))}),e(s,l),L()}const _a=aa,ra=U;export{va as D,_a as R,X as c};
