import"../chunks/CWj6FrbW.js";import"../chunks/BNWXpQSo.js";import{p as h,f as l,t as v,a as u,c as e,r as p,s as g}from"../chunks/CId4BCie.js";import{s as o}from"../chunks/CSj7lMIP.js";import{t as x,a as _}from"../chunks/BKnx-tix.js";import{i as d}from"../chunks/4jVyR5J-.js";import{p as m}from"../chunks/DKpjBS_Z.js";var b=x("<h1> </h1> <p> </p>",1);function A(i,f){h(f,!1),d();var r=b(),t=l(r),n=e(t,!0);p(t);var a=g(t,2),c=e(a,!0);p(a),v(()=>{var s;o(n,m.status),o(c,(s=m.error)==null?void 0:s.message)}),_(i,r),u()}export{A as component};
