[data-select-viewport],[data-combobox-viewport]{scrollbar-width:none!important;-ms-overflow-style:none!important;-webkit-overflow-scrolling:touch!important}[data-combobox-viewport]::-webkit-scrollbar{display:none!important}[data-select-viewport]::-webkit-scrollbar{display:none!important}.active-path.svelte-wnub8r{stroke:#3b82f6!important;stroke-width:3px!important}.dot-animation.svelte-wnub8r{filter:drop-shadow(0 0 2px rgba(59,130,246,.8))}.dark .dot-animation.svelte-wnub8r{fill:#93c5fd}
