import"../chunks/CWj6FrbW.js";import{t as _,c as l,r as n,s as x,p as T,L as i,f as D,a as y,i as f}from"../chunks/CId4BCie.js";import{t as p,a as g}from"../chunks/BKnx-tix.js";import{i as L,s as S,a as j}from"../chunks/B0ThxVmG.js";import{s as b}from"../chunks/CSj7lMIP.js";import{p as k}from"../chunks/DKpjBS_Z.js";import{E as w}from"../chunks/D5pf3YV6.js";const B=Object.freeze(Object.defineProperty({__proto__:null},Symbol.toStringTag,{value:"Module"}));var E=p('<p class="text-sm text-muted-foreground"> </p>'),O=p('<div class="space-y-1"><h2 class="text-2xl font-semibold tracking-tight"> </h2> <!></div>');function P(u,e){var a=O(),r=l(a),d=l(r,!0);n(r);var v=x(r,2);{var c=s=>{var t=E(),o=l(t,!0);n(t),_(()=>b(o,e.subtitle)),g(s,t)};L(v,s=>{e.subtitle&&s(c)})}n(a),_(()=>b(d,e.title)),g(u,a)}var $=p('<!> <div class="flex h-full w-full flex-col pr-4 pl-4 overflow-auto"><!></div>',1);function F(u,e){T(e,!0);const[a,r]=S(),d=()=>j(f(v),"$DebugTrace",a);i(()=>e.data.AgentConfig);let v=i(()=>e.data.DebugTrace),c=i(()=>d().data),s=i(()=>f(c).debugLog);var t=$(),o=D(t);P(o,{get title(){return k.params.id}});var m=x(o,2),h=l(m);w(h,{get events(){return f(s).events}}),n(m),g(u,t),y(),r()}export{F as component,B as universal};
