var m=s=>{throw TypeError(s)};var l=(s,t,e)=>t.has(s)||m("Cannot "+e);var i=(s,t,e)=>(l(s,t,"read from private field"),e?e.call(s):t.get(s)),n=(s,t,e)=>t.has(s)?m("Cannot add the same private member more than once"):t instanceof WeakSet?t.add(s):t.set(s,e),p=(s,t,e,r)=>(l(s,t,"write to private field"),r?r.call(s,e):t.set(s,e),e);import{o as u}from"./CSj7lMIP.js";import{c as M,I as b}from"./FgnODE38.js";import"./CWj6FrbW.js";import{p as $,f as g,x as v,a as x}from"./CId4BCie.js";import{c as _,a as w}from"./BKnx-tix.js";import{s as y}from"./D0aaoSU3.js";import{b as B,r as I}from"./B0ThxVmG.js";var a,o;class N{constructor(t,e){n(this,a);n(this,o);p(this,a,t),p(this,o,M(e))}get current(){return i(this,o).call(this),i(this,a).call(this)}}a=new WeakMap,o=new WeakMap;const V=/\(.+\)/;class z extends N{constructor(t,e){let r=V.test(t)?t:`(${t})`;const c=window.matchMedia(r);super(()=>c.matches,h=>u(c,"change",h))}}function A(s,t){$(t,!0);let e=I(t,["$$slots","$$events","$$legacy"]);b(s,B({name:"bot"},()=>e,{iconNode:[["path",{d:"M12 8V4H8"}],["rect",{width:"16",height:"12",x:"4",y:"8",rx:"2"}],["path",{d:"M2 14h2"}],["path",{d:"M20 14h2"}],["path",{d:"M15 13v2"}],["path",{d:"M9 13v2"}]],children:(c,h)=>{var d=_(),f=g(d);y(f,()=>t.children??v),w(c,d)},$$slots:{default:!0}})),x()}export{A as B,z as M};
