import{D as m,F as d,G as E,H as v,T as p,I as x,z as f,A as i,J as y,K as M}from"./CId4BCie.js";function h(r){var t=document.createElement("template");return t.innerHTML=r,t.content}function n(r,t){var e=v;e.nodes_start===null&&(e.nodes_start=r,e.nodes_end=t)}function A(r,t){var e=(t&p)!==0,l=(t&x)!==0,s,_=!r.startsWith("<!>");return()=>{if(f)return n(i,null),i;s===void 0&&(s=h(_?r:"<!>"+r),e||(s=d(s)));var a=l||E?document.importNode(s,!0):s.cloneNode(!0);if(e){var c=d(a),o=a.lastChild;n(c,o)}else n(a,a);return a}}function C(r,t,e="svg"){var l=!r.startsWith("<!>"),s=(t&p)!==0,_=`<${e}>${l?r:"<!>"+r}</${e}>`,a;return()=>{if(f)return n(i,null),i;if(!a){var c=h(_),o=d(c);if(s)for(a=document.createDocumentFragment();d(o);)a.appendChild(d(o));else a=d(o)}var u=a.cloneNode(!0);if(s){var g=d(u),T=u.lastChild;n(g,T)}else n(u,u);return u}}function D(r=""){if(!f){var t=m(r+"");return n(t,t),t}var e=i;return e.nodeType!==3&&(e.before(e=m()),M(e)),n(e,e),e}function F(){if(f)return n(i,null),i;var r=document.createDocumentFragment(),t=document.createComment(""),e=m();return r.append(t,e),n(t,e),r}function b(r,t){if(f){v.nodes_end=i,y();return}r!==null&&r.before(t)}export{b as a,D as b,F as c,n as d,h as e,C as n,A as t};
