import{m as o,d as m,b as t,n as p,g as f,o as v,q as b}from"./CId4BCie.js";function d(e){t===null&&o(),p&&t.l!==null?r(t).m.push(e):m(()=>{const n=f(e);if(typeof n=="function")return n})}function x(e){t===null&&o(),d(()=>()=>f(e))}function y(e,n,{bubbles:a=!1,cancelable:s=!1}={}){return new CustomEvent(e,{detail:n,bubbles:a,cancelable:s})}function h(){const e=t;return e===null&&o(),(n,a,s)=>{var l;const c=(l=e.s.$$events)==null?void 0:l[n];if(c){const i=v(c)?c.slice():[c],u=y(n,a,s);for(const _ of i)_.call(e.x,u);return!u.defaultPrevented}return!0}}function k(e){t===null&&o(),t.l===null&&b(),r(t).b.push(e)}function r(e){var n=e.l;return n.u??(n.u={a:[],b:[],m:[]})}export{x as a,k as b,h as c,d as o};
