import"../chunks/CWj6FrbW.js";import"../chunks/BNWXpQSo.js";import{B as o}from"../chunks/CId4BCie.js";import{t,a as i}from"../chunks/BKnx-tix.js";const l=Object.freeze(Object.defineProperty({__proto__:null},Symbol.toStringTag,{value:"Module"}));var a=t('<div class="grid auto-rows-min gap-4 md:grid-cols-3"><div class="aspect-video rounded-xl bg-muted/50"></div> <div class="aspect-video rounded-xl bg-muted/50"></div> <div class="aspect-video rounded-xl bg-muted/50"></div></div> <div class="min-h-[100vh] flex-1 rounded-xl bg-muted/50 md:min-h-min"></div>',1);function v(e){var d=a();o(2),i(e,d)}export{v as component,l as universal};
